@@ -1594,7 +1594,7 @@ TEST(aes_xts, reencipher)
 
 	TESTLIB_AES_NEW_MK_CHECK(type, mkvp, apqns);
 
-	if (type == ZPC_EC_KEY_TYPE_PVSECRET)
+	if (type == ZPC_AES_KEY_TYPE_PVSECRET)
 		GTEST_SKIP_("Skipping reencipher test. Not applicable for UV secrets.");
 
 	rc = zpc_aes_key_alloc(&aes_key1);
@@ -1765,7 +1765,7 @@ TEST(aes_xts, pvsecret_kat)
 	mkvp = testlib_env_aes_key_mkvp();
 	(void)testlib_env_aes_key_apqns(apqns);
 
-	if (type != ZPC_EC_KEY_TYPE_PVSECRET)
+	if (type != ZPC_AES_KEY_TYPE_PVSECRET)
 		GTEST_SKIP_("Skipping pvsecret_kat test. Only applicable for UV secrets.");
 
 	TESTLIB_AES_KERNEL_CAPS_CHECK(type);
@@ -1776,11 +1776,9 @@ TEST(aes_xts, pvsecret_kat)
 
 	TESTLIB_AES_XTS_KEY_SIZE_CHECK(size);
 
-	TESTLIB_EC_SW_CAPS_CHECK(type);
+	TESTLIB_AES_SW_CAPS_CHECK(type);
 
-	TESTLIB_EC_KERNEL_CAPS_CHECK(type, mkvp, apqns);
-
-	TESTLIB_EC_NEW_MK_CHECK(type, mkvp, apqns);
+	TESTLIB_AES_KERNEL_CAPS_CHECK(type);
 
 	rc = zpc_aes_key_alloc(&aes_key1);
 	EXPECT_EQ(rc, 0);
@@ -1847,9 +1845,13 @@ TEST(aes_xts, pvsecret_kat)
 		EXPECT_EQ(rc, 0);
 		if (mkvp != NULL) {
 			rc = zpc_aes_key_set_mkvp(aes_key3, mkvp);
-			EXPECT_EQ(rc, 0);
-			rc = zpc_aes_key_set_mkvp(aes_key4, mkvp);
-			EXPECT_EQ(rc, 0);
+			rc += zpc_aes_key_set_mkvp(aes_key4, mkvp);
+			if (type2 == ZPC_AES_KEY_TYPE_CCA_DATA && rc != 0) {
+				type2 = ZPC_AES_KEY_TYPE_EP11;
+				continue;
+			}
+			if (rc)
+				goto ret;
 		} else {
 			rc = zpc_aes_key_set_apqns(aes_key3, apqns);
 			EXPECT_EQ(rc, 0);
@@ -1867,9 +1869,9 @@ TEST(aes_xts, pvsecret_kat)
 		rc = zpc_aes_key_set_size(aes_key4, size);
 		EXPECT_EQ(rc, 0);
 
-		rc = testlib_set_aes_key_from_file(aes_key3, type2, size);
-		rc = testlib_set_aes_key_from_file(aes_key4, type2, size);
-		if (rc == ZPC_ERROR_IOCTLCLR2SECK2) {
+		rc = testlib_set_aes_key_from_file(aes_key3, type2, size, 0, 1);
+		rc += testlib_set_aes_key_from_file(aes_key4, type2, size, 0, 2);
+		if (type2 == ZPC_AES_KEY_TYPE_CCA_DATA && rc != 0) {
 			type2 = ZPC_AES_KEY_TYPE_EP11;
 			continue;
 		}
